---
name: Bug report
about: The compiler is not doing what I expected
title: "[BUG]"
labels: ''
assignees: ''

---

**Is this related to a PeakRDL sub-command?**
If so, please open an issue in the appropriate `PeakRDL-***` project: https://github.com/orgs/SystemRDL/repositories


**Describe the bug**
A clear and concise description of what the bug is.

Details like these can be helpful:
* Sample SystemRDL code
* Error message or example output
* Version numbers for the tool, Python, and OS


**Expected behavior**
A clear and concise description of what you expected to happen.


**Additional context**
Add any other context about the problem here.
